@@ -1,4 +1,4 @@
-/*      $Id: irrecord.c,v 5.42 2002/07/13 09:30:17 ranty Exp $      */
+/*      $Id: irrecord.c,v 5.54 2005/08/02 06:20:44 lirc Exp $      */
 
 /****************************************************************************
  ** irrecord.c **************************************************************
@@ -61,8 +61,13 @@ void set_toggle_bit(struct ir_remote *remote,ir_code xor);
 void get_pre_data(struct ir_remote *remote);
 void get_post_data(struct ir_remote *remote);
 #ifdef DEBUG
+typedef void (*remote_func)(struct ir_remote *remotes);
+
+void for_each_remote(struct ir_remote *remotes, remote_func func);
 void remove_pre_data(struct ir_remote *remote);
 void remove_post_data(struct ir_remote *remote);
+void invert_data(struct ir_remote *remote);
+void remove_trail(struct ir_remote *remote);
 #endif
 int get_lengths(struct ir_remote *remote,int force);
 struct lengths *new_length(lirc_t length);
@@ -185,8 +190,9 @@ int main(int argc,char **argv)
 	int force;
 	int retries;
 	struct ir_remote *remotes=NULL;
+	char *device=NULL;
 #ifdef DEBUG
-	int get_pre=0,get_post=0;
+	int get_pre=0,get_post=0,test=0,invert=0,trail=0;
 #endif
 
 	progname=argv[0];
@@ -205,11 +211,14 @@ int main(int argc,char **argv)
 #ifdef DEBUG
 			{"pre",no_argument,NULL,'p'},
 			{"post",no_argument,NULL,'P'},
+			{"test",no_argument,NULL,'t'},
+			{"invert",no_argument,NULL,'i'},
+			{"trail",no_argument,NULL,'T'},
 #endif
 			{0, 0, 0, 0}
 		};
 #ifdef DEBUG
-		c = getopt_long(argc,argv,"hvd:H:fpP",long_options,NULL);
+		c = getopt_long(argc,argv,"hvd:H:fpPtiT",long_options,NULL);
 #else
 		c = getopt_long(argc,argv,"hvd:H:f",long_options,NULL);
 #endif
@@ -235,8 +244,9 @@ int main(int argc,char **argv)
 				hw_print_drivers(stderr);
 				exit (EXIT_FAILURE);
 			}
+			break;
 		case 'd':
-			hw.device=optarg;
+			device=optarg;
 			break;
 		case 'f':
 			force=1;
@@ -248,6 +258,15 @@ int main(int argc,char **argv)
 		case 'P':
 			get_post=1;
 			break;
+		case 't':
+			test=1;
+			break;
+		case 'i':
+			invert=1;
+			break;
+		case 'T':
+			trail=1;
+			break;
 #endif
 		default:
 			printf("Try %s -h for help!\n",progname);
@@ -263,6 +282,10 @@ int main(int argc,char **argv)
 		fprintf(stderr,"%s: invalid argument count\n",progname);
 		exit(EXIT_FAILURE);
 	}
+	if(device!=NULL)
+	{
+		hw.device=device;
+	}
 	if(strcmp(hw.name, "null")==0)
 	{
 		fprintf(stderr,
@@ -286,14 +309,19 @@ int main(int argc,char **argv)
 			exit(EXIT_FAILURE);
 		}
 #ifdef DEBUG
-		remove_pre_data(remotes);
-		remove_post_data(remotes);
-		if(get_pre) get_pre_data(remotes);
-		if(get_post) get_post_data(remotes);
+		if(test)
+		{
+			if(trail) for_each_remote(remotes, remove_trail);
+			for_each_remote(remotes, remove_pre_data);
+			for_each_remote(remotes, remove_post_data);
+			if(get_pre) for_each_remote(remotes, get_pre_data);
+			if(get_post) for_each_remote(remotes, get_post_data);
+			if(invert) for_each_remote(remotes, invert_data);
 			
-		fprint_remotes(stdout,remotes);
-		free_config(remotes);
-		return(EXIT_SUCCESS);
+			fprint_remotes(stdout,remotes);
+			free_config(remotes);
+			return(EXIT_SUCCESS);
+		}
 #endif
 		remote=*remotes;
 		remote.name=NULL;
@@ -301,11 +329,15 @@ int main(int argc,char **argv)
 		remote.last_code=NULL;
 		remote.next=NULL;
 		remote.toggle_bit=0;
-		remote.bits=remote.pre_data_bits+
-			remote.bits+
-			remote.post_data_bits;
-		remote.pre_data_bits=0;
-		remote.post_data_bits=0;
+		if(remote.pre_p==0 && remote.pre_s==0 &&
+		   remote.post_p==0 && remote.post_s==0)
+		{
+			remote.bits=remote.pre_data_bits+
+				remote.bits+
+				remote.post_data_bits;
+			remote.pre_data_bits=0;
+			remote.post_data_bits=0;
+		}
 		if(remotes->next!=NULL)
 		{
 			fprintf(stderr,
@@ -428,8 +460,7 @@ int main(int argc,char **argv)
 				exit(EXIT_FAILURE);
 			}
 			printf("Creating config file in raw mode.\n");
-			remote.flags&=~(RC5|RC6|RCMM|SPACE_ENC);
-			remote.flags|=RAW_CODES;
+			set_protocol(&remote, RAW_CODES);
 			remote.eps=EPS;
 			remote.aeps=AEPS;
 			break;
@@ -518,7 +549,7 @@ int main(int argc,char **argv)
 			break;
 		}
 		
-		if(remote.flags&RAW_CODES)
+		if(is_raw(&remote))
 		{
 			flushhw();
 		}
@@ -532,7 +563,7 @@ int main(int argc,char **argv)
 		printf("\nNow hold down button \"%s\".\n",buffer);
 		fflush(stdout);
 		
-		if(remote.flags&RAW_CODES)
+		if(is_raw(&remote))
 		{
 			lirc_t data,sum;
 			unsigned int count;
@@ -686,7 +717,7 @@ int main(int argc,char **argv)
 		exit(EXIT_FAILURE);
 	}
 	
-	if(remote.flags&RAW_CODES)
+	if(is_raw(&remote))
 	{
 		return(EXIT_SUCCESS);
 	}
@@ -770,7 +801,7 @@ void flushhw(void)
 		if(hw.code_length%CHAR_BIT) size++;
 		break;
 	}
-	while(read(hw.fd,buffer,size)==size);
+    while(read(hw.fd,buffer,size)==size);
 }
 
 int resethw(void)
@@ -896,12 +927,14 @@ int get_toggle_bit(struct ir_remote *remote)
 			break;
 		}
 		hw.rec_func(remote);
-		if(is_rc6(remote))
+		if(is_rc6(remote) && remote->rc6_mask==0)
 		{
-			for(remote->toggle_bit=1;
-			    remote->toggle_bit<=remote->bits;
-			    remote->toggle_bit++)
+			int i;
+			ir_code mask;
+
+			for(i=0,mask=1;i<remote->bits;i++,mask<<=1)
 			{
+				remote->rc6_mask=mask;
 				success=hw.decode_func(remote,&pre,&code,&post,
 						       &repeat_flag,
 						       &remaining_gap);
@@ -911,7 +944,7 @@ int get_toggle_bit(struct ir_remote *remote)
 					break;
 				}
 			}
-			if(success==0) remote->toggle_bit=0;
+			if(success==0) remote->rc6_mask=0;
 		}
 		else
 		{
@@ -948,6 +981,10 @@ int get_toggle_bit(struct ir_remote *remote)
 				repeats++;
 			}
 		}
+		else
+		{
+			retries--;
+		}
 	}
 	if(!found)
 	{
@@ -1030,8 +1067,16 @@ void get_pre_data(struct ir_remote *remote)
 	if(codes->name==NULL) return; /* at least 2 codes needed */
 	while(codes->name!=NULL)
 	{
+		struct ir_code_node *loop;
+		
 		mask&=~(last^codes->code);
 		last=codes->code;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			mask&=~(last^loop->code);
+			last=loop->code;
+		}
+		
 		codes++;
 	}
 	count=0;
@@ -1067,7 +1112,13 @@ void get_pre_data(struct ir_remote *remote)
 		codes=remote->codes;
 		while(codes->name!=NULL)
 		{
+			struct ir_code_node *loop;
+			
 			codes->code&=~mask;
+			for(loop=codes->next; loop!=NULL; loop=loop->next)
+			{
+				loop->code&=~mask;
+			}
 			codes++;
 		}
 	}
@@ -1089,8 +1140,15 @@ void get_post_data(struct ir_remote *remote)
 	if(codes->name==NULL) return; /* at least 2 codes needed */
 	while(codes->name!=NULL)
 	{
+		struct ir_code_node *loop;
+		
 		mask&=~(last^codes->code);
 		last=codes->code;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			mask&=~(last^loop->code);
+			last=loop->code;
+		}
 		codes++;
 	}
 	count=0;
@@ -1119,67 +1177,168 @@ void get_post_data(struct ir_remote *remote)
 		codes=remote->codes;
 		while(codes->name!=NULL)
 		{
+			struct ir_code_node *loop;
+			
 			codes->code=codes->code>>count;
+			for(loop=codes->next; loop!=NULL; loop=loop->next)
+			{
+				loop->code=loop->code>>count;
+			}
 			codes++;
 		}
 	}
 }
 
 #ifdef DEBUG
-void remove_pre_data(struct ir_remote *remotes)
+void for_each_remote(struct ir_remote *remotes, remote_func func)
 {
-	struct ir_ncode *codes;
 	struct ir_remote *remote;
 	
 	remote=remotes;
 	while(remote!=NULL)
 	{
-		if(remote->pre_data_bits==0)
-		{
-			remote=remote->next;
-			continue;
-		}
-
-		codes=remote->codes;
-		while(codes->name!=NULL)
-		{
-			codes->code|=remote->pre_data<<remote->bits;
-			codes++;
-		}
-		remote->bits+=remote->pre_data_bits;
-		remote->pre_data=0;
-		remote->pre_data_bits=0;
+		func(remote);
 		remote=remote->next;
 	}
 }
 
-void remove_post_data(struct ir_remote *remotes)
+void remove_pre_data(struct ir_remote *remote)
 {
 	struct ir_ncode *codes;
 	
-	struct ir_remote *remote;
-	
-	remote=remotes;
-	while(remote!=NULL)
+	if(remote->pre_data_bits==0 ||
+	   remote->pre_p!=0 || remote->pre_s!=0)
 	{
-		if(remote->post_data_bits==0)
-		{
-			remote=remote->next;
-			continue;
-		}
-		
-		codes=remote->codes;
-		while(codes->name!=NULL)
-		{
-			codes->code<<=remote->post_data_bits;
-			codes->code|=remote->post_data;
-			codes++;
-		}
-		remote->bits+=remote->post_data_bits;
-		remote->post_data=0;
-		remote->post_data_bits=0;
 		remote=remote->next;
+		return;
 	}
+	
+	codes=remote->codes;
+	while(codes->name!=NULL)
+	{
+		struct ir_code_node *loop;
+		
+		codes->code|=remote->pre_data<<remote->bits;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			loop->code|=remote->pre_data<<remote->bits;
+		}
+		codes++;
+	}
+	remote->bits+=remote->pre_data_bits;
+	remote->pre_data=0;
+	remote->pre_data_bits=0;
+}
+
+void remove_post_data(struct ir_remote *remote)
+{
+	struct ir_ncode *codes;
+	
+	if(remote->post_data_bits==0)
+	{
+		remote=remote->next;
+		return;
+	}
+	
+	codes=remote->codes;
+	while(codes->name!=NULL)
+	{
+		struct ir_code_node *loop;
+		
+		codes->code<<=remote->post_data_bits;
+		codes->code|=remote->post_data;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			loop->code<<=remote->post_data_bits;
+			loop->code|=remote->post_data;
+		}
+		codes++;
+	}
+	remote->bits+=remote->post_data_bits;
+	remote->post_data=0;
+	remote->post_data_bits=0;
+}
+
+void invert_data(struct ir_remote *remote)
+{
+	struct ir_ncode *codes;
+	ir_code mask;
+	lirc_t p,s;
+		
+	/* swap one, zero */
+	p=remote->pone;
+	s=remote->sone;
+	remote->pone=remote->pzero;
+	remote->sone=remote->szero;
+	remote->pzero=p;
+	remote->szero=s;
+	
+	/* invert pre_data */
+	if(has_pre(remote))
+	{
+		mask=gen_mask(remote->pre_data_bits);
+		remote->pre_data^=mask;
+	}
+	/* invert post_data */
+	if(has_post(remote))
+	{
+		mask=gen_mask(remote->post_data_bits);
+		remote->post_data^=mask;
+	}
+	
+	if(remote->bits==0)
+	{
+		remote=remote->next;
+		return;
+	}
+	
+	/* invert codes */
+	mask=gen_mask(remote->bits);
+	codes=remote->codes;
+	while(codes->name!=NULL)
+	{
+		struct ir_code_node *loop;
+		
+		codes->code^=mask;
+		for(loop=codes->next; loop!=NULL; loop=loop->next)
+		{
+			loop->code^=mask;
+		}
+		codes++;
+	}
+}
+
+void remove_trail(struct ir_remote *remote)
+{
+	int extra_bit;
+	
+	if(!is_space_enc(remote)) return;
+	
+	if(remote->ptrail == 0) return;
+	
+	if(expect(remote, remote->pone, remote->pzero) ||
+	   expect(remote, remote->pzero, remote->pone)) return;
+	
+	if(!(expect(remote, remote->sone, remote->szero) &&
+	     expect(remote, remote->szero, remote->sone))) return;
+	
+	if(expect(remote, remote->ptrail, remote->pone))
+	{
+		extra_bit = 1;
+	}
+	else if(expect(remote, remote->ptrail, remote->pzero))
+	{
+		extra_bit = 0;
+	}
+	else
+	{
+		return;
+	}
+	
+	remote->post_data_bits++;
+	remote->post_data<<=1;
+	remote->post_data|=extra_bit;
+	remote->ptrail=0;
 }
 #endif
 
@@ -1651,7 +1810,7 @@ void get_scheme(struct ir_remote *remote)
 		/* this is not yet the
 		   number of bits */
 		remote->bits=length;
-		remote->flags|=SPACE_ENC;
+		set_protocol(remote, SPACE_ENC);
 		return;
 	}
 	else
@@ -1690,12 +1849,12 @@ void get_scheme(struct ir_remote *remote)
 				    calc_signal(max2s)<500))
 				{
 					printf("RC-6 remote control found.\n");
-					remote->flags|=RC6;
+					set_protocol(remote, RC6);
 				}
 				else
 				{
 					printf("RC-5 remote control found.\n");
-					remote->flags|=RC5;
+					set_protocol(remote, RC5);
 				}
 				return;
 			}
@@ -1705,7 +1864,7 @@ void get_scheme(struct ir_remote *remote)
 	printf("Suspicious data length: %u.\n",length);
 	/* this is not yet the number of bits */
 	remote->bits=length;
-	remote->flags|=SPACE_ENC;
+	set_protocol(remote, SPACE_ENC);
 }
 
 struct lengths *get_max_length(struct lengths *first,unsigned int *sump)
@@ -2054,6 +2213,11 @@ int get_data_length(struct ir_remote *remote)
 					remote->sone=s1;
 					remote->pzero=min(p1,p2);
 					remote->szero=s1;
+					if(expect(remote,remote->ptrail,p1) ||
+					   expect(remote,remote->ptrail,p2))
+					{
+						remote->ptrail=0;
+					}
 				}
 				else
 				{
