@@ -35,15 +35,11 @@
 
 
 #include <linux/version.h>
-#if LINUX_VERSION_CODE >= 0x020100
-#define KERNEL_2_1
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,0)
-#define KERNEL_2_3
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 2, 18)
+#error "**********************************************************"
+#error " Sorry, this driver needs kernel version 2.2.18 or higher "
+#error "**********************************************************"
 #endif
-#else
-#define KERNEL_2_0
-#endif
-
 #include <linux/module.h>
 
 #ifdef HAVE_CONFIG_H
@@ -61,6 +57,7 @@
 #warning "******************************************"
 #endif
 
+#include <linux/module.h>
 #include <linux/sched.h>
 #include <linux/errno.h>
 #include <linux/signal.h>
@@ -76,9 +73,7 @@
 #include <linux/wait.h>
 #include <linux/mm.h>
 #include <linux/delay.h>
-#ifdef KERNEL_2_1
 #include <linux/poll.h>
-#endif
 #include <asm/system.h>
 #include <asm/segment.h>
 #include <asm/io.h>
@@ -95,6 +90,8 @@
 #include <linux/timer.h>
 
 #include "drivers/lirc.h"
+#include "drivers/lirc_dev/lirc_dev.h"
+#include "drivers/kcompat.h"
 
 /* SECTION: Definitions */
 
@@ -142,11 +139,11 @@ static int irq=IRQ_Ser2ICP;
 #define LIRC_ON_SA1100_TRANSMITTER_LATENCY 0
 
 /* pulse/space ratio of 50/50 */
-unsigned long pulse_width = (13-LIRC_ON_SA1100_TRANSMITTER_LATENCY);
+static unsigned long pulse_width = (13-LIRC_ON_SA1100_TRANSMITTER_LATENCY);
 /* 1000000/freq-pulse_width */
-unsigned long space_width = (13-LIRC_ON_SA1100_TRANSMITTER_LATENCY);
-unsigned int freq = 38000;      /* modulation frequency */
-unsigned int duty_cycle = 50;   /* duty cycle of 50% */
+static unsigned long space_width = (13-LIRC_ON_SA1100_TRANSMITTER_LATENCY);
+static unsigned int freq = 38000;      /* modulation frequency */
+static unsigned int duty_cycle = 50;   /* duty cycle of 50% */
 
 #endif
 
@@ -167,11 +164,17 @@ unsigned int duty_cycle = 50;   /* duty cycle of 50% */
 /* must be longer than TIME_CONST */
 #define SIR_TIMEOUT	(HZ*5/100)
 
-static int major = LIRC_MAJOR;
-
 #ifndef LIRC_ON_SA1100
+#ifndef LIRC_IRQ
+#define LIRC_IRQ 4
+#endif
+#ifndef LIRC_PORT
+#define LIRC_PORT 0x3e8
+#endif
+
 static int io = LIRC_PORT;
 static int irq = LIRC_IRQ;
+static int threshold = 3;
 #endif
 
 static spinlock_t timer_lock = SPIN_LOCK_UNLOCKED;
@@ -182,11 +185,7 @@ static struct timeval last_tv = {0, 0};
 static struct timeval last_intr_tv = {0, 0};
 static int last_value = 0;
 
-#ifdef KERNEL_2_3
 static DECLARE_WAIT_QUEUE_HEAD(lirc_read_queue);
-#else
-static struct wait_queue * lirc_read_queue = NULL;
-#endif
 
 static spinlock_t hardware_lock = SPIN_LOCK_UNLOCKED;
 static spinlock_t dev_lock = SPIN_LOCK_UNLOCKED;
@@ -196,18 +195,19 @@ static lirc_t rx_buf[RBUF_LEN]; unsigned int rx_tail = 0, rx_head = 0;
 static lirc_t tx_buf[WBUF_LEN];
 #endif
 
+static int debug = 0;
+#define dprintk(fmt, args...)                                     \
+	do{                                                       \
+		if(debug) printk(KERN_DEBUG LIRC_DRIVER_NAME ": " \
+                                 fmt, ## args);                   \
+	}while(0)
+
 /* SECTION: Prototypes */
 
 /* Communication with user-space */
 static int lirc_open(struct inode * inode, struct file * file);
-#ifdef KERNEL_2_1
 static int lirc_close(struct inode * inode, struct file *file);
 static unsigned int lirc_poll(struct file * file, poll_table * wait);
-#else
-static void lirc_close(struct inode * inode, struct file *file);
-static int lirc_select(struct inode * inode, struct file * file,
-		int type, select_table * wait);
-#endif
 static ssize_t lirc_read(struct file * file, char * buf, size_t count,
 		loff_t * ppos);
 static ssize_t lirc_write(struct file * file, const char * buf, size_t n, loff_t * pos);
@@ -219,7 +219,8 @@ static int init_chrdev(void);
 static void drop_chrdev(void);
 #endif
 	/* Hardware */
-static void sir_interrupt(int irq, void * dev_id, struct pt_regs * regs);
+static irqreturn_t sir_interrupt(int irq, void * dev_id,
+				 struct pt_regs * regs);
 #ifndef LIRC_SIR_TEKRAM
 static void send_space(unsigned long len);
 static void send_pulse(unsigned long len);
@@ -233,12 +234,12 @@ int init_module(void);
 void cleanup_module(void);
 
 #ifdef LIRC_ON_SA1100
-void inline on(void)
+static void inline on(void)
 {
 	PPSR|=PPC_TXD2;
 }
   
-void inline off(void)
+static void inline off(void)
 {
 	PPSR&=~PPC_TXD2;
 }
@@ -284,19 +285,12 @@ static int lirc_open(struct inode * inode, struct file * file)
 	return 0;
 }
 
-#ifdef KERNEL_2_1
 static int lirc_close(struct inode * inode, struct file *file)
-#else
-static void lirc_close(struct inode * inode, struct file *file)
-#endif
 {
 	MOD_DEC_USE_COUNT;
-#ifdef KERNEL_2_1
 	return 0;
-#endif
 }
 
-#ifdef KERNEL_2_1
 static unsigned int lirc_poll(struct file * file, poll_table * wait)
 {
 	poll_wait(file, &lirc_read_queue, wait);
@@ -304,34 +298,18 @@ static unsigned int lirc_poll(struct file * file, poll_table * wait)
 		return POLLIN | POLLRDNORM;
 	return 0;
 }
-#else
-static int lirc_select(struct inode * inode, struct file * file,
-		int type, select_table * wait)
-{
-	if (type != SEL_IN)
-		return 0;
-	if (rx_head != rx_tail)
-		return 1;
-	select_wait(&lirc_read_queue, wait);
-	return 0;
-}
-#endif
 
 static ssize_t lirc_read(struct file * file, char * buf, size_t count,
 		loff_t * ppos)
 {
 	int n=0;
 	int retval = 0;
-#ifdef KERNEL_2_3
 	DECLARE_WAITQUEUE(wait,current);
-#else
-	struct wait_queue wait={current,NULL};
-#endif
 	
 	if(n%sizeof(lirc_t)) return(-EINVAL);
 	
 	add_wait_queue(&lirc_read_queue,&wait);
-	current->state=TASK_INTERRUPTIBLE;
+	set_current_state(TASK_INTERRUPTIBLE);
 	while(n<count)
 	{
 		if(rx_head!=rx_tail)
@@ -342,13 +320,8 @@ static ssize_t lirc_read(struct file * file, char * buf, size_t count,
 			{
 				return retval;
 			}
-#ifdef KERNEL_2_1
 			copy_to_user((void *) buf+n,(void *) (rx_buf+rx_head),
 				     sizeof(lirc_t));
-#else
-			memcpy_tofs((void *) buf+n,(void *) (rx_buf+rx_head),
-				    sizeof(lirc_t));
-#endif
 			rx_head=(rx_head+1)&(RBUF_LEN-1);
 			n+=sizeof(lirc_t);
 		}
@@ -359,25 +332,17 @@ static ssize_t lirc_read(struct file * file, char * buf, size_t count,
 				retval=-EAGAIN;
 				break;
 			}
-#                       ifdef KERNEL_2_1
 			if(signal_pending(current))
 			{
 				retval=-ERESTARTSYS;
 				break;
 			}
-#                       else
-			if(current->signal & ~current->blocked)
-			{
-				retval=-EINTR;
-				break;
-			}
-#                       endif
 			schedule();
-			current->state=TASK_INTERRUPTIBLE;
+			set_current_state(TASK_INTERRUPTIBLE);
 		}
 	}
 	remove_wait_queue(&lirc_read_queue,&wait);
-	current->state=TASK_RUNNING;
+	set_current_state(TASK_RUNNING);
 	return (n ? n : retval);
 }
 static ssize_t lirc_write(struct file * file, const char * buf, size_t n, loff_t * pos)
@@ -401,7 +366,7 @@ static ssize_t lirc_write(struct file * file, const char * buf, size_t n, loff_t
 	/* disable receiver */
 	Ser2UTCR3=0;
 #endif
-	save_flags(flags);cli();
+	local_irq_save(flags);
 	while (1) {
 		if (i >= n)
 			break;
@@ -414,7 +379,7 @@ static ssize_t lirc_write(struct file * file, const char * buf, size_t n, loff_t
 			send_space(tx_buf[i]);
 		i++;
 	}
-	restore_flags(flags);
+	local_irq_restore(flags);
 #ifdef LIRC_ON_SA1100
 	off();
 	udelay(1000); /* wait 1ms for IR diode to recover */
@@ -467,40 +432,17 @@ static int lirc_ioctl(struct inode *node,struct file *filep,unsigned int cmd,
 	case LIRC_GET_FEATURES:
 	case LIRC_GET_SEND_MODE:
 	case LIRC_GET_REC_MODE:
-#ifdef KERNEL_2_0
-		retval = verify_area(VERIFY_WRITE, (unsigned long *) arg,
-			sizeof(unsigned long));
-		if (retval)
-			break;
-#else
-		retval =
-#endif
-		put_user(value, (unsigned long *) arg);
+		retval = put_user(value, (unsigned long *) arg);
 		break;
 
 	case LIRC_SET_SEND_MODE:
 	case LIRC_SET_REC_MODE:
-#ifdef KERNEL_2_0
-		retval = verify_area(VERIFY_READ, (unsigned long *) arg,
-			sizeof(unsigned long));
-		if (retval)
-			break;
-		value = get_user((unsigned long *) arg);
-#else
 		retval = get_user(value, (unsigned long *) arg);
-#endif
 		break;
 #ifdef LIRC_ON_SA1100
 	case LIRC_SET_SEND_DUTY_CYCLE:
-#               ifdef KERNEL_2_1
 		retval=get_user(ivalue,(unsigned int *) arg);
 		if(retval) return(retval);
-#               else
-		retval=verify_area(VERIFY_READ,(unsigned int *) arg,
-				   sizeof(unsigned int));
-		if(result) return(result);
-		ivalue=get_user((unsigned int *) arg);
-#               endif
 		if(ivalue<=0 || ivalue>100) return(-EINVAL);
 		/* (ivalue/100)*(1000000/freq) */
 		duty_cycle=ivalue;
@@ -512,15 +454,8 @@ static int lirc_ioctl(struct inode *node,struct file *filep,unsigned int cmd,
 			space_width-=LIRC_ON_SA1100_TRANSMITTER_LATENCY;
 		break;
 	case LIRC_SET_SEND_CARRIER:
-#               ifdef KERNEL_2_1
 		retval=get_user(ivalue,(unsigned int *) arg);
 		if(retval) return(retval);
-#               else
-		retval=verify_area(VERIFY_READ,(unsigned int *) arg,
-				   sizeof(unsigned int));
-		if(retval) return(retval);
-		ivalue=get_user((unsigned int *) arg);
-#               endif
 		if(ivalue>500000 || ivalue<20000) return(-EINVAL);
 		freq=ivalue;
 		pulse_width=(unsigned long) duty_cycle*10000/freq;
@@ -563,11 +498,7 @@ static void add_read_queue(int flag, unsigned long val)
 	unsigned int new_rx_tail;
 	lirc_t newval;
 
-#ifdef DEBUG_SIGNAL
-	printk(KERN_DEBUG LIRC_DRIVER_NAME
-		": add flag %d with val %lu\n",
-		flag,val);
-#endif
+	dprintk("add flag %d with val %lu\n", flag, val);
 
 	newval = val & PULSE_MASK;
 
@@ -591,9 +522,7 @@ static void add_read_queue(int flag, unsigned long val)
 	}
 	new_rx_tail = (rx_tail + 1) & (RBUF_LEN - 1);
 	if (new_rx_tail == rx_head) {
-#               ifdef DEBUG
-		printk(KERN_WARNING LIRC_DRIVER_NAME ": Buffer overrun.\n");
-#               endif
+		dprintk("Buffer overrun.\n");
 		return;
 	}
 	rx_buf[rx_tail] = newval;
@@ -605,32 +534,55 @@ static struct file_operations lirc_fops =
 {
 	read:    lirc_read,
 	write:   lirc_write,
-#ifdef KERNEL_2_1
 	poll:    lirc_poll,
-#else
-	select:  lirc_select,
-#endif
 	ioctl:   lirc_ioctl,
 	open:    lirc_open,
 	release: lirc_close,
 };
 
-#ifdef MODULE
-int init_chrdev(void)
+static int set_use_inc(void* data)
 {
-	int retval;
+#if WE_DONT_USE_LOCAL_OPEN_CLOSE
+	MOD_INC_USE_COUNT;
+#endif
+       return 0;
+}
 
-	retval = register_chrdev(major, LIRC_DRIVER_NAME, &lirc_fops);
-	if (retval < 0) {
+static void set_use_dec(void* data)
+{
+#if WE_DONT_USE_LOCAL_OPEN_CLOSE
+	MOD_DEC_USE_COUNT;
+#endif
+}
+static struct lirc_plugin plugin = {
+       name:           LIRC_DRIVER_NAME,
+       minor:          -1,
+       code_length:    1,
+       sample_rate:    0,
+       data:           NULL,
+       add_to_buf:     NULL,
+       get_queue:      NULL,
+       set_use_inc:    set_use_inc,
+       set_use_dec:    set_use_dec,
+       fops:           &lirc_fops,
+       owner:          THIS_MODULE,
+};
+
+
+#ifdef MODULE
+static int init_chrdev(void)
+{
+	plugin.minor = lirc_register_plugin(&plugin);
+	if (plugin.minor < 0) {
 		printk(KERN_ERR LIRC_DRIVER_NAME ": init_chrdev() failed.\n");
-		return retval;
+		return -EIO;
 	}
 	return 0;
 }
 
 static void drop_chrdev(void)
 {
-	unregister_chrdev(major, LIRC_DRIVER_NAME);
+	lirc_unregister_plugin(plugin.minor);
 }
 #endif
 
@@ -669,10 +621,7 @@ static void sir_timeout(unsigned long data)
 #endif
 		/* determine 'virtual' pulse end: */
 	 	pulse_end = delta(&last_tv, &last_intr_tv);
-#ifdef DEBUG_SIGNAL
-		printk(KERN_DEBUG LIRC_DRIVER_NAME
-			": timeout add %d for %lu usec\n",last_value,pulse_end);
-#endif
+		dprintk("timeout add %d for %lu usec\n",last_value,pulse_end);
 		add_read_queue(last_value,pulse_end);
 		last_value = 0;
 		last_tv=last_intr_tv;
@@ -680,7 +629,8 @@ static void sir_timeout(unsigned long data)
 	spin_unlock_irqrestore(&timer_lock, flags);		
 }
 
-static void sir_interrupt(int irq, void * dev_id, struct pt_regs * regs)
+static irqreturn_t sir_interrupt(int irq, void * dev_id,
+				 struct pt_regs * regs)
 {
 	unsigned char data;
 	struct timeval curr_tv;
@@ -698,18 +648,18 @@ static void sir_interrupt(int irq, void * dev_id, struct pt_regs * regs)
 	while (status & UTSR0_EIF)
 	{
 		int bstat;
+
+		if(debug) {
+			dprintk("EIF\n");
+			bstat = Ser2UTSR1;
 		
-#ifdef DEBUG
-		printk("EIF\n");
-		bstat = Ser2UTSR1;
-		
-		if (bstat & UTSR1_FRE)
-			printk("frame error\n");
-		if (bstat & UTSR1_ROR)
-			printk("receive fifo overrun\n");
-		if(bstat&UTSR1_PRE)
-			printk("parity error\n");
-#endif
+			if (bstat & UTSR1_FRE)
+				dprintk("frame error\n");
+			if (bstat & UTSR1_ROR)
+				dprintk("receive fifo overrun\n");
+			if (bstat & UTSR1_PRE)
+				dprintk("parity error\n");
+		}
 		
 		bstat = Ser2UTDR;
 		n++;
@@ -722,12 +672,8 @@ static void sir_interrupt(int irq, void * dev_id, struct pt_regs * regs)
 		deltv = delta(&last_tv, &curr_tv);
 		do
 		{
-#ifdef DEBUG_SIGNAL
-			printk(KERN_DEBUG LIRC_DRIVER_NAME": t %lu , d %d\n",
-			       deltintrtv,(int)data);
-#endif
 			data=Ser2UTDR;
-			//printk("data: %d\n",data);
+			dprintk("%d data: %u\n", n, (unsigned int) data);
 			n++;
 		}
 		while(status&UTSR0_RID && /* do not empty fifo in
@@ -785,16 +731,12 @@ static void sir_interrupt(int irq, void * dev_id, struct pt_regs * regs)
 				do_gettimeofday(&curr_tv);
 				deltv = delta(&last_tv, &curr_tv);
 				deltintrtv = delta(&last_intr_tv, &curr_tv);
-#ifdef DEBUG_SIGNAL
-				printk(KERN_DEBUG LIRC_DRIVER_NAME": t %lu , d %d\n",deltintrtv,(int)data);
-#endif
-				/* if nothing came in last 2 cycles,
+				dprintk("t %lu , d %d\n", deltintrtv, (int)data);
+				/* if nothing came in last X cycles,
 				   it was gap */
-				if (deltintrtv > TIME_CONST * 2) {
+				if (deltintrtv > TIME_CONST * threshold) {
 					if (last_value) {
-#ifdef DEBUG_SIGNAL
-						printk(KERN_DEBUG LIRC_DRIVER_NAME ": GAP\n");
-#endif
+						dprintk("GAP\n");
 						/* simulate signal change */
 						add_read_queue(last_value,
 							       deltv-
@@ -842,10 +784,11 @@ static void sir_interrupt(int irq, void * dev_id, struct pt_regs * regs)
 		}
 	}
 #endif
+	return IRQ_RETVAL(IRQ_HANDLED);
 }
 
 #ifdef LIRC_ON_SA1100
-void send_pulse(unsigned long length)
+static void send_pulse(unsigned long length)
 {
 	unsigned long k,delay;
 	int flag;
@@ -871,7 +814,7 @@ void send_pulse(unsigned long length)
 	off();
 }
 
-void send_space(unsigned long length)
+static void send_space(unsigned long length)
 {
 	if(length==0) return;
 	off();
@@ -931,7 +874,7 @@ static inline int sa1100_irda_set_power_collie(int state)
 
 static int init_hardware(void)
 {
-	int flags;
+	unsigned long flags;
 	
 	spin_lock_irqsave(&hardware_lock, flags);
 	/* reset UART */
@@ -1078,7 +1021,7 @@ static int init_hardware(void)
 
 static void drop_hardware(void)
 {
-	int flags;
+	unsigned long flags;
 
 	spin_lock_irqsave(&hardware_lock, flags);
 
@@ -1113,14 +1056,13 @@ static int init_port(void)
 {
 	int retval;
 	
-#ifndef LIRC_ON_SA1100
 	/* get I/O port access and IRQ line */
-	retval = check_region(io, 8);
-	if (retval < 0) {
+#ifndef LIRC_ON_SA1100
+	if(request_region(io, 8, LIRC_DRIVER_NAME) == NULL)
+	{
 		printk(KERN_ERR LIRC_DRIVER_NAME
-			": i/o port 0x%.4x already in use.\n",
-			io);
-		return retval;
+		       ": i/o port 0x%.4x already in use.\n", io);
+		return -EBUSY;
 	}
 #endif
 	retval = request_irq(irq, sir_interrupt, SA_INTERRUPT,
@@ -1132,7 +1074,6 @@ static int init_port(void)
 		return retval;
 	}
 #ifndef LIRC_ON_SA1100
-	request_region(io, 8, LIRC_DRIVER_NAME);
 	printk(KERN_INFO LIRC_DRIVER_NAME
 		": I/O port 0x%.4x, IRQ %d.\n",
 		io, irq);
@@ -1147,15 +1088,8 @@ static int init_port(void)
 
 static void drop_port(void)
 {
-	disable_irq(irq);
 	free_irq(irq, NULL);
-#ifdef KERNEL_2_3
 	del_timer_sync(&timerlist);
-#else
-	start_bh_atomic();
-	del_timer(&timerlist);
-	end_bh_atomic();
-#endif
 #ifndef LIRC_ON_SA1100
 	release_region(io, 8);
 #endif
@@ -1228,7 +1162,7 @@ static void drop_port(void)
 
 static void init_act200(void)
 {
-  int i;
+	int i;
 	__u8 control[] = {
 		ACT200L_REG15,
 		ACT200L_REG13 | ACT200L_SHDW,
@@ -1307,18 +1241,15 @@ static void init_act200(void)
 }
 #endif
 
-int init_lirc_sir(void)
+static int init_lirc_sir(void)
 {
 	int retval;
 
-#ifdef KERNEL_2_3
 	init_waitqueue_head(&lirc_read_queue);
-#endif
 	retval = init_port();
 	if (retval < 0)
 		return retval;
 	init_hardware();
-	enable_irq(irq);
 	printk(KERN_INFO LIRC_DRIVER_NAME
 		": Installed.\n");
 	return 0;
@@ -1326,39 +1257,6 @@ int init_lirc_sir(void)
 
 #ifdef MODULE
 
-#ifdef KERNEL_2_1
-
-#ifdef LIRC_SIR_TEKRAM
-MODULE_AUTHOR("Christoph Bartelmus");
-MODULE_DESCRIPTION("Infrared receiver driver for Tekram Irmate 210");
-#elif defined(LIRC_ON_SA1100)
-MODULE_AUTHOR("Christoph Bartelmus");
-MODULE_DESCRIPTION("LIRC driver for StrongARM SA1100 embedded microprocessor");
-#elif defined(LIRC_SIR_ACTISYS_ACT200L)
-MODULE_AUTHOR("Karl Bongers");
-MODULE_DESCRIPTION("LIRC driver for Actisys Act200L");
-#else
-MODULE_AUTHOR("Milan Pikula");
-MODULE_DESCRIPTION("Infrared receiver driver for SIR type serial ports");
-#endif
-
-#ifdef LIRC_ON_SA1100
-MODULE_PARM(irq, "i");
-MODULE_PARM_DESC(irq, "Interrupt (16)");
-#else
-MODULE_PARM(io, "i");
-MODULE_PARM_DESC(io, "I/O address base (0x3f8 or 0x2f8)");
-MODULE_PARM(irq, "i");
-MODULE_PARM_DESC(irq, "Interrupt (4 or 3)");
-#endif
-
-#ifdef MODULE_LICENSE
-MODULE_LICENSE("GPL");
-#endif
-
-EXPORT_NO_SYMBOLS;
-#endif
-
 int init_module(void)
 {
 	int retval;
@@ -1381,4 +1279,39 @@ void cleanup_module(void)
 	drop_port();
 	printk(KERN_INFO LIRC_DRIVER_NAME ": Uninstalled.\n");
 }
+
+#ifdef LIRC_SIR_TEKRAM
+MODULE_DESCRIPTION("Infrared receiver driver for Tekram Irmate 210");
+MODULE_AUTHOR("Christoph Bartelmus");
+#elif defined(LIRC_ON_SA1100)
+MODULE_DESCRIPTION("LIRC driver for StrongARM SA1100 embedded microprocessor");
+MODULE_AUTHOR("Christoph Bartelmus");
+#elif defined(LIRC_SIR_ACTISYS_ACT200L)
+MODULE_DESCRIPTION("LIRC driver for Actisys Act200L");
+MODULE_AUTHOR("Karl Bongers");
+#else
+MODULE_DESCRIPTION("Infrared receiver driver for SIR type serial ports");
+MODULE_AUTHOR("Milan Pikula");
 #endif
+MODULE_LICENSE("GPL");
+
+#ifdef LIRC_ON_SA1100
+module_param(irq, int, 0444);
+MODULE_PARM_DESC(irq, "Interrupt (16)");
+#else
+module_param(io, int, 0444);
+MODULE_PARM_DESC(io, "I/O address base (0x3f8 or 0x2f8)");
+
+module_param(irq, int, 0444);
+MODULE_PARM_DESC(irq, "Interrupt (4 or 3)");
+
+module_param(threshold, int, 0444);
+MODULE_PARM_DESC(threshold, "space detection threshold (3)");
+#endif
+
+module_param(debug, bool, 0644);
+MODULE_PARM_DESC(debug, "Enable debugging messages");
+
+EXPORT_NO_SYMBOLS;
+
+#endif /* MODULE */
