@@ -1,6 +1,6 @@
 #! /bin/sh
 
-LIRC_VERSION="0.6.6"
+LIRC_VERSION="0.7.2"
 
 #############################################################################
 ## Default Values
@@ -23,13 +23,16 @@ LIRC_DRIVER="serial"
 LIRC_MAJOR=61
 SELECTED_DRIVER=""
 DRIVER_PARAMETER="com1"
+DRIVER_PARAM_TYPE=""
 SOFT_CARRIER="on"
-TRANSMITTER="off"
+TRANSMITTER="on"
+IGOR="off"
 TIMER=65536
 X11_WINDOWS="on"
 DEBUG="off"
 NO_DAEMONIZE="off"
 NO_LONG_CODES="off"
+DYNCODES="off"
 USE_SYSLOG="off"
 
 #############################################################################
@@ -57,7 +60,13 @@ GetSelectedDriver ()
     COM1="off"; COM2="off"; COM3="off"; COM4="off"
     LPT1="off"; LPT2="off"; LPT3="off"; USER="off"
     IRTTY="none"
-    if   test "$DRIVER_PARAMETER" = "com1"; then COM1="on"; LIRC_PORT=$COM1_PORT; LIRC_IRQ=$COM1_IRQ
+
+    if   test "$DRIVER_PARAMETER" = "btty"; then IRTTY="/dev/rfcomm0"; LIRC_PORT="none"; LIRC_IRQ="none"
+    elif test "$DRIVER_PARAMETER" = "ttyUSB1"; then COM1="on"; IRTTY="/dev/ttyUSB0"; LIRC_PORT="none"; LIRC_IRQ="none"
+    elif test "$DRIVER_PARAMETER" = "ttyUSB2"; then COM2="on"; IRTTY="/dev/ttyUSB1"; LIRC_PORT="none"; LIRC_IRQ="none"
+    elif test "$DRIVER_PARAMETER" = "ttyUSB3"; then COM3="on"; IRTTY="/dev/ttyUSB2"; LIRC_PORT="none"; LIRC_IRQ="none"
+    elif test "$DRIVER_PARAMETER" = "ttyUSB4"; then COM4="on"; IRTTY="/dev/ttyUSB3"; LIRC_PORT="none"; LIRC_IRQ="none"
+    elif test "$DRIVER_PARAMETER" = "com1"; then COM1="on"; LIRC_PORT=$COM1_PORT; LIRC_IRQ=$COM1_IRQ
     elif test "$DRIVER_PARAMETER" = "com2"; then COM2="on"; LIRC_PORT=$COM2_PORT; LIRC_IRQ=$COM2_IRQ
     elif test "$DRIVER_PARAMETER" = "com3"; then COM3="on"; LIRC_PORT=$COM3_PORT; LIRC_IRQ=$COM3_IRQ
     elif test "$DRIVER_PARAMETER" = "com4"; then COM4="on"; LIRC_PORT=$COM4_PORT; LIRC_IRQ=$COM4_IRQ
@@ -100,14 +109,7 @@ GetPortAndIrq ()
 
 SetPortAndIrq ()
     {
-    if test "$LIRC_DRIVER" = "serial" -o \
-	    "$LIRC_DRIVER" = "sir" -o \
-	    "$LIRC_DRIVER" = "tekram" -o \
-	    "$LIRC_DRIVER" = "act200l" -o \
-	    "$LIRC_DRIVER" = "packard_bell" -o \
-	    "$LIRC_DRIVER" = "animax" -o \
-	    "$LIRC_DRIVER" = "irdeo" -o \
-	    "$LIRC_DRIVER" = "irdeo_remote"; then
+    if test "$DRIVER_PARAM_TYPE" = "com"; then
         {
         dialog --clear --backtitle "$BACKTITLE" \
                --title "Specify I/O base address and IRQ of your hardware" \
@@ -133,7 +135,7 @@ SetPortAndIrq ()
 	    return 1;
         fi
         }
-    elif test "$LIRC_DRIVER" = "parallel"; then
+    elif test "$DRIVER_PARAM_TYPE" = "lpt"; then
         {
         dialog --clear --backtitle "$BACKTITLE" \
                --title "Specify I/O base address and IRQ of your hardware" \
@@ -157,10 +159,7 @@ SetPortAndIrq ()
 	    return 1;
         fi
         }
-    elif test "$LIRC_DRIVER" = "remotemaster" -o "$LIRC_DRIVER" = "irman" -o \
-	"$LIRC_DRIVER" = "logitech" -o "$LIRC_DRIVER" = "pctv" -o \
-	"$LIRC_DRIVER" = "creative" -o "$LIRC_DRIVER" = "slinke" -o \
-        "$LIRC_DRIVER" = "silitek" -o "$LIRC_DRIVER" = "realmagic"; then
+    elif test "$DRIVER_PARAM_TYPE" = "tty"; then
 	{
         dialog --clear --backtitle "$BACKTITLE" \
                --title "Select tty to use" \
@@ -184,6 +183,30 @@ SetPortAndIrq ()
 	else
 	    return 1;
         fi
+    elif test "$DRIVER_PARAM_TYPE" = "ttyUSB"; then
+	{
+        dialog --clear --backtitle "$BACKTITLE" \
+               --title "Select tty to use" \
+               --radiolist "$SET_TTY_TEXT" 13 74 6 \
+                 1 "/dev/ttyUSB0" $COM1 \
+                 2 "/dev/ttyUSB1" $COM2 \
+                 3 "/dev/ttyUSB2" $COM3 \
+                 4 "/dev/ttyUSB3" $COM4 \
+               2> $TEMP
+	}
+        if test "$?" = "0"; then
+            {
+	    set `cat $TEMP`
+            if   test "$1" = "1"; then DRIVER_PARAMETER="ttyUSB1"
+            elif test "$1" = "2"; then DRIVER_PARAMETER="ttyUSB2"
+            elif test "$1" = "3"; then DRIVER_PARAMETER="ttyUSB3"
+            elif test "$1" = "4"; then DRIVER_PARAMETER="ttyUSB4"
+            fi
+            GetSelectedDriver
+            }
+	else
+	    return 1;
+        fi
     fi
     return 0;
     }
@@ -196,19 +219,22 @@ DriverOptions ()
         {
         dialog --clear --backtitle "$BACKTITLE" \
                --title "Driver specific Options" \
-               --checklist "" 10 74 2 \
+               --checklist "" 10 74 3 \
                  1 "With transmitter diode" $TRANSMITTER \
                  2 "Software generated carrier" $SOFT_CARRIER \
+                 3 "Igor Cesko's variation" $IGOR \
                2> $TEMP
         if test "$?" = "0"; then
             {
 	    set -- `cat $TEMP`
             SOFT_CARRIER="off"
 	    TRANSMITTER="off"
+	    IGOR="off"
             for ITEM in $@; do
                 {
-                if   test $ITEM = "\"1\""; then TRANSMITTER="on";
-                elif test $ITEM = "\"2\""; then SOFT_CARRIER="on";
+                if   test $ITEM = "1" || test $ITEM = "\"1\""; then TRANSMITTER="on";
+                elif test $ITEM = "2" || test $ITEM = "\"2\""; then SOFT_CARRIER="on";
+                elif test $ITEM = "3" || test $ITEM = "\"3\""; then IGOR="on";
                 fi
                 }
             done
@@ -239,186 +265,13 @@ DriverOptions ()
 
 ConfigDriver ()
     {
-    dialog --clear --backtitle "$BACKTITLE" \
-           --title "Select your driver" \
-           --menu "$CONFIG_DRIVER_TEXT" 16 74 9 \
-             1 "Home-brew (16x50 UART compatible serial port)" \
-             2 "Home-brew (parallel port)" \
-	     3 "Home-brew (soundcard input, EXPERIMENTAL)" \
-	     4 "Other serial port devices" \
-	     5 "TV card" \
-	     6 "IrDA hardware" \
-	     7 "PDAs" \
-	     8 "Network (UDP)" \
-	     9 "None (network connections only)" 2> $TEMP
-
+    . ./setup-driver.sh
     if test "$?" = "0"; then
-        {
-	set `cat $TEMP`
-        if   test "$1" = "1"; then LIRC_DRIVER=serial;   DRIVER_PARAMETER=com1;
-        elif test "$1" = "2"; then LIRC_DRIVER=parallel; DRIVER_PARAMETER=lpt1;
-        elif test "$1" = "3"; then LIRC_DRIVER=dsp;      DRIVER_PARAMETER=none;
-        elif test "$1" = "4"; then
-	    # "Other serial port devices"
-	    dialog --clear --backtitle "$BACKTITLE" \
-                --title "Select your driver" \
-		--menu "$CONFIG_DRIVER_TEXT" 19 74 12 \
-			1 "Anir Multimedia Magic" \
-			2 "CARACA" \
-			3 "Creative Infra Receiver" \
-			4 "IRdeo" \
-			5 "IRdeo Remote" \
-			6 "Irman / UIR" \
-			7 "Logitech/AST" \
-			8 "Miro PCTV receiver" \
-			9 "Packard Bell receiver" \
-			0 "Pinnacle Systems PCTV (pro) receiver" \
-			a "PixelView RemoteMaster RC2000/RC3000" \
-			b "REALmagic (bundled with Hollywood Plus DVD card)" \
-			c "Slink-e (receive only)" \
-                        d "Silitek SM-1000" \
-			e "Tekram Irmate 210 (16x50 UART compatible serial port)" 2> $TEMP;
-	    if test "$?" = "0"; then
-		{
-		set `cat $TEMP`
-		if   test "$1" = "1"; then LIRC_DRIVER=animax;       DRIVER_PARAMETER=com1;
-		elif test "$1" = "2"; then LIRC_DRIVER=caraca;       DRIVER_PARAMETER=tty1;
-		elif test "$1" = "3"; then LIRC_DRIVER=creative;     DRIVER_PARAMETER=tty1;
-		elif test "$1" = "4"; then LIRC_DRIVER=irdeo;        DRIVER_PARAMETER=com1;
-		elif test "$1" = "5"; then LIRC_DRIVER=irdeo_remote; DRIVER_PARAMETER=com1;
-		elif test "$1" = "6"; then LIRC_DRIVER=irman;        DRIVER_PARAMETER=tty1;
-		elif test "$1" = "7"; then LIRC_DRIVER=logitech;     DRIVER_PARAMETER=tty1;
-		elif test "$1" = "8"; then LIRC_DRIVER=pctv;         DRIVER_PARAMETER=tty1;
-		elif test "$1" = "9"; then LIRC_DRIVER=packard_bell; DRIVER_PARAMETER=com1;
-		elif test "$1" = "0"; then LIRC_DRIVER=pctv;         DRIVER_PARAMETER=tty1;
-		elif test "$1" = "a"; then LIRC_DRIVER=remotemaster; DRIVER_PARAMETER=tty1;
-		elif test "$1" = "b"; then LIRC_DRIVER=realmagic;    DRIVER_PARAMETER=tty1;
-		elif test "$1" = "c"; then LIRC_DRIVER=slinke;       DRIVER_PARAMETER=tty3;
-		elif test "$1" = "d"; then LIRC_DRIVER=silitek;      DRIVER_PARAMETER=tty1;
-		elif test "$1" = "e"; then LIRC_DRIVER=tekram;       DRIVER_PARAMETER=com1;
-		fi
-		}
-	    else
-		return;
-	    fi;
-
-        elif test "$1" = "5"; then
-	    dialog --clear --backtitle "$BACKTITLE" \
-                --title "Select your driver" \
-		--menu "$CONFIG_DRIVER_TEXT" 19 74 12\
-                        1 "Askey Magic TView CPH03x (card=1)" \
-			2 "Askey/Typhoon/Anubis Magic TView CPH051/061 (bt878) (card=24)" \
-			3 "AverMedia TV card (TVCapture, TVPhone) (card=6)" \
-			4 "AverMedia TV card (TVCapture98, TVPhone98) (card=13/41)" \
-			5 "BestBuy Easy TV (BT848) (card=55)" \
-			6 "BestBuy Easy TV (BT878) (card=62)" \
-			7 "Chronos Video Shuttle II (card=35)" \
-                        8 "Dynalink Magic TView (card=48)" \
-			9 "FlyVideo II (card=8)" \
-			0 "FlyVideo 98 (card=30)" \
-			a "FlyVideo 98/FM /2000S (card=56)" \
-			b "Hauppauge TV card (new I2C layer required)" \
-			c "Hauppauge DVB-s card (ver. 2.1)" \
-			d "KNC ONE TV Station (-/SE/PRO/RDS)" \
-			e "Lenco MXTV-9578 CP (card=50)" \
-			f "Miro PCTV serial port receiver" \
-			g "Phoebe Tv Master + FM (card=22)" \
-                        h "PixelView PlayTV PAK (card=50)" \
-                        i "Pixelview PlayTV pro (card=37)" \
-                        j "Pixelview PlayTV (bt878) (Prolink PV-BT878P+, card=16)" \
-			k "Prolink PV-BT878P+4E (card=50)" \
-			l "Prolink PV-BT878P+9B (PlayTV Pro rev.9B FM+NICAM) (card=72)" \
-			m "ProVideo PV951 (card=42)" \
-			n "Technisat MediaFocus I" \
-			o "Tekram M230 Mach64 (and others bt829 based)" \
-			p "TView99 CPH063 (card=38)" \
-			q "Typhoon TView RDS / FM Stereo (card=53)" \
-			r "Winfast TV2000 (card=34)" 2> $TEMP;
-
-	    if test "$?" = "0"; then
-		{
-		set `cat $TEMP`
-		if   test "$1" = "1"; then LIRC_DRIVER=cph03x;          DRIVER_PARAMETER=none;
-		elif test "$1" = "2"; then LIRC_DRIVER=cph06x;          DRIVER_PARAMETER=none;
-		elif test "$1" = "3"; then LIRC_DRIVER=avermedia;       DRIVER_PARAMETER=none;
-		elif test "$1" = "4"; then LIRC_DRIVER=avermedia98;     DRIVER_PARAMETER=none;
-		elif test "$1" = "5"; then LIRC_DRIVER=bestbuy;		DRIVER_PARAMETER=none;
-		elif test "$1" = "6"; then LIRC_DRIVER=bestbuy2;	DRIVER_PARAMETER=none;
-		elif test "$1" = "7"; then LIRC_DRIVER=chronos;         DRIVER_PARAMETER=none;
-		elif test "$1" = "8"; then LIRC_DRIVER=cph03x;          DRIVER_PARAMETER=none;
-		elif test "$1" = "9"; then LIRC_DRIVER=flyvideo;        DRIVER_PARAMETER=none;
-		elif test "$1" = "0"; then LIRC_DRIVER=fly98;           DRIVER_PARAMETER=none;
-		elif test "$1" = "a"; then LIRC_DRIVER=fly98;           DRIVER_PARAMETER=none;
-		elif test "$1" = "b"; then LIRC_DRIVER=hauppauge;       DRIVER_PARAMETER=none;
-		elif test "$1" = "c"; then LIRC_DRIVER=hauppauge_dvb;   DRIVER_PARAMETER=none;
-		elif test "$1" = "d"; then LIRC_DRIVER=knc_one;         DRIVER_PARAMETER=none;
-		elif test "$1" = "e"; then LIRC_DRIVER=pixelview_pak;   DRIVER_PARAMETER=none;
-		elif test "$1" = "f"; then LIRC_DRIVER=pctv;            DRIVER_PARAMETER=tty1;
-		elif test "$1" = "g"; then LIRC_DRIVER=cph06x;          DRIVER_PARAMETER=none;
-		elif test "$1" = "h"; then LIRC_DRIVER=pixelview_pak;   DRIVER_PARAMETER=none;
-		elif test "$1" = "i"; then LIRC_DRIVER=pixelview_pro;   DRIVER_PARAMETER=none;
-		elif test "$1" = "j"; then LIRC_DRIVER=pixelview_bt878; DRIVER_PARAMETER=none;
-		elif test "$1" = "k"; then LIRC_DRIVER=pixelview_pak;   DRIVER_PARAMETER=none;
-		elif test "$1" = "l"; then LIRC_DRIVER=pixelview_pro;   DRIVER_PARAMETER=none;
-		elif test "$1" = "m"; then LIRC_DRIVER=provideo;        DRIVER_PARAMETER=none;
-		elif test "$1" = "n"; then LIRC_DRIVER=mediafocusI;     DRIVER_PARAMETER=none;
-		elif test "$1" = "o"; then LIRC_DRIVER=tekram_bt829;    DRIVER_PARAMETER=none;
-		elif test "$1" = "p"; then LIRC_DRIVER=cph06x;          DRIVER_PARAMETER=none;
-		elif test "$1" = "q"; then LIRC_DRIVER=knc_one;         DRIVER_PARAMETER=none;
-		elif test "$1" = "r"; then LIRC_DRIVER=winfast_tv2000;  DRIVER_PARAMETER=none;
-		fi
-		}
-	    else
-		return;
-	    fi;
-        elif test "$1" = "6"; then
-	    dialog --clear --backtitle "$BACKTITLE" \
-                --title "Select your driver" \
-		--menu "$CONFIG_DRIVER_TEXT" 11 74 4 \
-			1 "SIR IrDA (built-in IR ports)" \
-			2 "Tekram Irmate 210 (16x50 UART compatible serial port)" \
-			3 "ITE IT8712/IT8705 CIR port (experimental, 2.4.x required)" \
-			4 "Actisys Act200L SIR driver support" 2> $TEMP;
-	    if test "$?" = "0"; then
-		{
-		set `cat $TEMP`
-		if   test "$1" = "1"; then LIRC_DRIVER=sir;          DRIVER_PARAMETER=com3;
-		elif test "$1" = "2"; then LIRC_DRIVER=tekram;       DRIVER_PARAMETER=com1;
-		elif test "$1" = "3"; then LIRC_DRIVER=it87;         DRIVER_PARAMETER=none;
-		elif test "$1" = "4"; then LIRC_DRIVER=act200l;      DRIVER_PARAMETER=com1;
-		fi
-		}
-	    else
-		return;
-	    fi;
-	elif test "$1" = "7"; then 
-	    dialog --clear --backtitle "$BACKTITLE" \
-                --title "Select your driver" \
-		--menu "$CONFIG_DRIVER_TEXT" 11 74 3 \
-			1 "HP iPAQ" \
-			2 "Sharp Zaurus" 2> $TEMP;
-	    if test "$?" = "0"; then
-		{
-		set `cat $TEMP`
-		if   test "$1" = "1"; then LIRC_DRIVER=sa1100; DRIVER_PARAMETER=none;
-		elif test "$1" = "2"; then LIRC_DRIVER=sa1100; DRIVER_PARAMETER=none;
-		fi
-		}
-	    else
-		return 1;
-	    fi;
-
-        elif test "$1" = "8"; then LIRC_DRIVER=udp;     DRIVER_PARAMETER=none;
-        elif test "$1" = "9"; then LIRC_DRIVER=none;    DRIVER_PARAMETER=none;
-	fi
-	if test "$?" = "0"; then
-	    GetSelectedDriver
-	    SetPortAndIrq
-	    if test "$?" = "0"; then
-		DriverOptions
-	    fi
-	fi
-        }
+        GetSelectedDriver
+        SetPortAndIrq
+        if test "$?" = "0"; then
+            DriverOptions
+        fi
     fi
     }
 
@@ -428,25 +281,27 @@ ConfigSoftware ()
     {
     dialog --clear --backtitle "$BACKTITLE" \
            --title "Software Configuration" \
-           --checklist "$CONFIG_SOFTWARE_TEXT" 13 74 5 \
+           --checklist "$CONFIG_SOFTWARE_TEXT" 14 74 6 \
              1 "Compile tools for X-Windows" $X11_WINDOWS \
              2 "Compile with DEBUG code" $DEBUG \
              3 "Disable daemonize" $NO_DAEMONIZE \
              4 "Disable long codes" $NO_LONG_CODES \
-             5 "Use syslogd instead of own log-file" $USE_SYSLOG 2>$TEMP
+             5 "Use syslogd instead of own log-file" $USE_SYSLOG \
+             6 "Enable dynamic codes" $DYNCODES 2>$TEMP
 
     if test "$?" = "0"; then
         {
 	set -- `cat $TEMP`
         X11_WINDOWS="off"; DEBUG="off"; NO_DAEMONIZE="off"; NO_LONG_CODES="off"
-        USE_SYSLOG="off"
+        USE_SYSLOG="off"; DYNCODES="off"
         for ITEM in $@; do
             {
-            if   test $ITEM = "\"1\""; then X11_WINDOWS="on"
-            elif test $ITEM = "\"2\""; then DEBUG="on"
-            elif test $ITEM = "\"3\""; then NO_DAEMONIZE="on"
-            elif test $ITEM = "\"4\""; then NO_LONG_CODES="on"
-            elif test $ITEM = "\"5\""; then USE_SYSLOG="on"
+            if   test $ITEM = "1" || test $ITEM = "\"1\""; then X11_WINDOWS="on"
+            elif test $ITEM = "2" || test $ITEM = "\"2\""; then DEBUG="on"
+            elif test $ITEM = "3" || test $ITEM = "\"3\""; then NO_DAEMONIZE="on"
+            elif test $ITEM = "4" || test $ITEM = "\"4\""; then NO_LONG_CODES="on"
+            elif test $ITEM = "5" || test $ITEM = "\"5\""; then USE_SYSLOG="on"
+            elif test $ITEM = "6" || test $ITEM = "\"6\""; then DYNCODES="on"
             fi
             }
         done
@@ -466,22 +321,25 @@ SaveConfig ()
     echo "DRIVER_PARAMETER=$DRIVER_PARAMETER" >>$CONFIG
     echo "SOFT_CARRIER=$SOFT_CARRIER" >>$CONFIG
     echo "TRANSMITTER=$TRANSMITTER" >>$CONFIG
+    echo "IGOR=$IGOR" >>$CONFIG
     echo "TIMER=$TIMER" >>$CONFIG
     echo "X11_WINDOWS=$X11_WINDOWS" >>$CONFIG
     echo "DEBUG=$DEBUG" >>$CONFIG
     echo "NO_DAEMONIZE=$NO_DAEMONIZE" >>$CONFIG
     echo "NO_LONG_CODES=$NO_LONG_CODES" >>$CONFIG
     echo "USE_SYSLOG=$USE_SYSLOG" >>$CONFIG
+    echo "DYNCODES=$DYNCODES" >>$CONFIG
     chmod 666 $CONFIG
 
     echo '#!/bin/bash' >$START
     echo >>$START
     echo "./configure \\" >>$START
-    echo "--with-module-dir=/lib/modules/`uname -r`/misc \\" >>$START
+    echo "--with-moduledir=/lib/modules/`uname -r`/misc \\" >>$START
     if   test "$LIRC_DRIVER" = "serial"; then
         {
         if test "$SOFT_CARRIER" = "off"; then echo "--without-soft-carrier \\" >>$START; fi
         if test "$TRANSMITTER" = "on"; then echo "--with-transmitter \\" >>$START; fi
+        if test "$IGOR" = "on"; then echo "--with-igor \\" >>$START; fi
         }
     elif test "$LIRC_DRIVER" = "parallel"; then
         {
@@ -489,10 +347,7 @@ SaveConfig ()
 	else echo "--without-timer \\" >>$START;
 	fi
         }
-    elif test "$LIRC_DRIVER" = "irman" -o "$LIRC_DRIVER" = "remotemaster" -o \
-	"$LIRC_DRIVER" = "logitech" -o "$LIRC_DRIVER" = "pctv" -o \
-	"$LIRC_DRIVER" = "slinke" -o "$LIRC_DRIVER" = "silitek" -o \
-        "$LIRC_DRIVER" = "realmagic"; then
+    elif test "$DRIVER_PARAM_TYPE" = "tty" -o "$DRIVER_PARAM_TYPE" = "ttyUSB" -o "$LIRC_DRIVER" = "bte"; then
         {
 	echo "--with-tty=$IRTTY \\" >>$START
 	}
@@ -502,6 +357,7 @@ SaveConfig ()
     if test "$NO_DAEMONIZE" = "on"; then echo "--disable-daemonize \\" >>$START; fi
     if test "$NO_LONG_CODES" = "on"; then echo "--disable-long-codes \\" >>$START; fi
     if test "$USE_SYSLOG" = "on"; then echo "--with-syslog \\" >>$START; fi
+    if test "$DYNCODES" = "on"; then echo "--enable-dyncodes \\" >>$START; fi
     echo "--with-driver=$LIRC_DRIVER \\" >>$START
     echo "--with-major=$LIRC_MAJOR \\" >>$START
     echo "--with-port=$LIRC_PORT \\" >>$START
@@ -523,7 +379,10 @@ fi
 if test -f $CONFIG; then
     {
     echo "Loading saved configuration from $CONFIG"
-    . $CONFIG
+    case $CONFIG in
+    */*) . $CONFIG ;;
+    *) . ./$CONFIG ;;
+    esac
     sleep 1
     }
 fi
@@ -534,7 +393,7 @@ while test "$EXIT" != "yes"; do
     {
     dialog --clear --backtitle "$BACKTITLE" \
            --title "Mainmenu" \
-           --menu "$MAIN_MENU_TEXT" 14 74 5 \
+           --menu "$MAIN_MENU_TEXT" 13 74 5 \
              1 "Driver configuration ($SELECTED_DRIVER)" \
              2 "Software configuration" \
              3 "Save configuration & run configure" \
@@ -569,7 +428,10 @@ while test "$EXIT" != "yes"; do
 done
 #clear
 rm -f $TEMP
-echo "Written by <karsten.scheibler@bigfoot.de>, 1999-JUN-28"
+echo "setup.sh written by Karsten Scheibler, 1999-JUN-28"
+echo
+echo "If you have problems or questions please consult the mailing list"
+echo "<http://lists.sourceforge.net/mailman/listinfo/lirc-list>"
 echo
 echo $MESSAGE
 if test "$CONFIGURE" = "yes"; then
